==> open-xchange-documents-backend_7.8.0.orig.tar.bz2: open-xchange-documents-backend-7.8.0/com.openexchange.office.realtime/src/com/openexchange/office/realtime/tools/DebugHelper.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */
package com.openexchange.office.realtime.tools;

import org.json.JSONArray;
import org.json.JSONObject;

import com.openexchange.office.realtime.impl.ConnectionStatus;
import com.openexchange.office.realtime.impl.UserData;


public class DebugHelper {

    /**
     * Print all client user ids for debug purpose.
     *
     * @param connectionStatus The connection status where the active clients are stored within.
     */
    public static void debugLogActiveClients(final org.apache.commons.logging.Log log, final ConnectionStatus connectionStatus) {
        if ((null != connectionStatus) && (null != log)) {
            final JSONArray activeUsers = connectionStatus.getActiveUsers();
            for (int i = 0; i < activeUsers.length(); i++) {
                final JSONObject activeUser = activeUsers.optJSONObject(i);
                if (null != activeUser) {
                    String userId = activeUser.optString("userId", null);
                    log.debug("RT connection: Member = " + ((null != userId) ? userId : "unknown"));
                }
            }
        }
    }

    public static void debugLogClientParameters(final org.apache.commons.logging.Log log, final String folderId, final String fileId, final String app, boolean newDocLoaded, final JSONObject jsonRequest) {
        if (log.isDebugEnabled()) {
            Boolean useLocalStorage = null;
            try {
                useLocalStorage = jsonRequest.getBoolean("useLocalStorage");
            } catch (Exception e) {
                // Can be ignored, this is just an optional value
            }

            StringBuilder strBuf = new StringBuilder("RT connection: onJoin called with connect data for document: ");
            strBuf.append(getDocumentFolderAndFileId(folderId, fileId));
            strBuf.append(" UseLocalStorage=");
            strBuf.append((null == useLocalStorage) ? "unknown" : useLocalStorage);
            strBuf.append(" app=");
            strBuf.append(app);
            strBuf.append(" newDocument=");
            strBuf.append(newDocLoaded);
            log.debug(strBuf.toString());
        }
    }

    /**
     * Provides the folder and file id that this connection is associated with.
     *
     * @return A string which contains the folder and file id separated by a colon. If an id is unknown "n/a" is used instead.
     */
    public static String getDocumentFolderAndFileId(final String folderId, final String fileId) {
        final StringBuffer buf = new StringBuffer(32);

        buf.append((folderId == null) ? "n/a" : folderId);
        buf.append(".");
        buf.append((fileId == null) ? "n/a" : fileId);

        return buf.toString();
    }

    public static String getDocumentFolderAndFileId(final UserData userData) {
        final String folderId = (null != userData) ? userData.getFolderId() : null;
        final String fileId = (null != userData) ? userData.getFileId() : null;

        return getDocumentFolderAndFileId(folderId, fileId);
    }

}

==> open-xchange-documents-backend_7.8.3.orig.tar.bz2: open-xchange-documents-backend-7.8.3/com.openexchange.office.realtime/src/com/openexchange/office/realtime/tools/DebugHelper.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */
package com.openexchange.office.realtime.tools;

import org.json.JSONArray;
import org.json.JSONObject;

import com.openexchange.office.realtime.impl.ConnectionStatus;
import com.openexchange.office.tools.user.UserData;


public class DebugHelper {

    /**
     * Print all client user ids for debug purpose.
     *
     * @param connectionStatus The connection status where the active clients are stored within.
     */
    public static void debugLogActiveClients(final org.apache.commons.logging.Log log, final ConnectionStatus connectionStatus) {
        if ((null != connectionStatus) && (null != log)) {
            final JSONArray activeUsers = connectionStatus.getActiveUsers();
            for (int i = 0; i < activeUsers.length(); i++) {
                final JSONObject activeUser = activeUsers.optJSONObject(i);
                if (null != activeUser) {
                    String userId = activeUser.optString("userId", null);
                    log.debug("RT connection: Member = " + ((null != userId) ? userId : "unknown"));
                }
            }
        }
    }

    public static void debugLogClientParameters(final org.apache.commons.logging.Log log, final String folderId, final String fileId, final String app, boolean newDocLoaded, final JSONObject jsonRequest) {
        if (log.isDebugEnabled()) {
            Boolean useLocalStorage = null;
            try {
                useLocalStorage = jsonRequest.getBoolean("useLocalStorage");
            } catch (Exception e) {
                // Can be ignored, this is just an optional value
            }

            StringBuilder strBuf = new StringBuilder("RT connection: onJoin called with connect data for document: ");
            strBuf.append(getDocumentFolderAndFileId(folderId, fileId));
            strBuf.append(" UseLocalStorage=");
            strBuf.append((null == useLocalStorage) ? "unknown" : useLocalStorage);
            strBuf.append(" app=");
            strBuf.append(app);
            strBuf.append(" newDocument=");
            strBuf.append(newDocLoaded);
            log.debug(strBuf.toString());
        }
    }

    /**
     * Provides the folder and file id that this connection is associated with.
     *
     * @return A string which contains the folder and file id separated by a colon. If an id is unknown "n/a" is used instead.
     */
    public static String getDocumentFolderAndFileId(final String folderId, final String fileId) {
        final StringBuffer buf = new StringBuffer(32);

        buf.append((folderId == null) ? "n/a" : folderId);
        buf.append(".");
        buf.append((fileId == null) ? "n/a" : fileId);

        return buf.toString();
    }

    public static String getDocumentFolderAndFileId(final UserData userData) {
        final String folderId = (null != userData) ? userData.getFolderId() : null;
        final String fileId = (null != userData) ? userData.getFileId() : null;

        return getDocumentFolderAndFileId(folderId, fileId);
    }

}
